@@ -7,6 +7,7 @@ import inspect
 import functools
 import sys
 from enum import Enum, unique
+import signal
 
 
 def is_Windows():
@@ -429,7 +430,13 @@ def indexOf(arr, value):
     
     return -1
     
+def indexFor(arr, fn):
+    for i, val in enumerate(arr):
+        if fn(val):
+            return i
     
+    return -1
+
 class _DecoratorContextManager:
     """Allow a context manager to be used as a decorator"""
 
@@ -514,7 +521,22 @@ class Timer(_DecoratorContextManager):
         if self.logger:
             self.logger.info(msg)
         else:
-            print(msg)            
+            print(msg)
+
+class Timeout:
+    """Timeout class using ALARM signal."""
+    def __init__(self, sec):
+        self.sec = sec
+ 
+    def __enter__(self):
+        signal.signal(signal.SIGALRM, self.raise_timeout)
+        signal.alarm(self.sec)
+ 
+    def __exit__(self, *args):
+        signal.alarm(0)    # disable alarm
+
+    def raise_timeout(self, *args):
+        raise Exception("runtime timeout")
 
 def setitem(arr, *args):
     *indices, index, value = args
@@ -548,12 +570,27 @@ def getitem(data, *indices):
 
 
 def splice(arr, index, num, *args):
-    del arr[index: index + num]
-    
-    for arg in args:
-        arr.insert(index, arg)
-        index += 1
-        
+    assignment = []
+    insertion = []
+
+    for i, arg in enumerate(args):
+        if i < num:
+            assignment.append(arg)
+        else:
+            insertion.append(arg)
+
+    if len(assignment) < num:
+        num = len(assignment)
+        arr[index: index + num] = assignment
+        del arr[index + num:]
+    else:
+        arr[index: index + num] = assignment
+
+        index += num
+        for arg in insertion:
+            arr.insert(index, arg)
+            index += 1
+
     return arr
 
 def split_filename(filename):
@@ -590,18 +627,29 @@ def clip(this, min, max):
 
 def deleteIndices(arr, fn, postprocess=None):
     indicesToDelete = []
+    is_binary = fn.__code__.co_argcount > 1
     for i in range(len(arr)):
-        if fn(arr, i):
+        if fn(arr, i) if is_binary else fn(arr[i]):
             indicesToDelete.append(i)
+
+    if postprocess:
+        is_binary = postprocess.__code__.co_argcount > 1
             
     if indicesToDelete:
         indicesToDelete.reverse()
+        
+        if not isinstance(arr, list):
+            arr = [*arr]
+
         for i in indicesToDelete:
             if postprocess:
-                postprocess(arr, i)
+                if is_binary:
+                    postprocess(arr, i)
+                else: 
+                    postprocess(arr[i])
             del arr[i]
             
-        return True
+        return arr
      
 def batches(listOfElement, batch_size):
     batches = [None] * ((len(listOfElement) + batch_size - 1) // batch_size)
