@@ -55,6 +55,8 @@ class EmptySet(SymbolicSet):
         if lhs.is_EmptySet:
             return True
         
+    def __iter__(self):  # Get iterator object on iter
+        return RangeIterator(Range(0, 0))
     
 class Union(SymbolicSet):
     is_Union = True
@@ -354,6 +356,24 @@ class Range(SymbolicSet):
     def __gt__(self, that):
         return self.start >= that.stop 
 
+    def __iter__(self):  # Get iterator object on iter
+        return RangeIterator(self)
+
+
+class RangeIterator:
+    def __init__(self, range):
+        self.start = range.start
+        self.stop = range.stop
+        self.current = range.start
+    
+    def __next__(self):
+        if self.current >= self.stop:
+            raise StopIteration
+        
+        current = self.current
+        self.current += 1
+        return current
+    
 
 class Range2D(SymbolicSet):
     is_Range2D = True
